@@ -1,5 +1,10 @@
 import yake
-from removedor import removedor
+from bs4 import BeautifulSoup as bs
+
+def removedor(t):
+    t = str(t)
+    x = bs(t, 'html.parser').text
+    return x
 
 def removedordepalavraschaves(t):
 	text = removedor(t)
